# README #

Pyrateshield is an intuiative program to design the radiation shielding of rooms
in a nuclear medicine or radiology hospital department.


## Installing pyrateshield

Pyrateshield is available as a standalone windows executable or can be
installed in a python environment:

[code]pip install pyrateshield[/code]

type [code]pyrateshield[/code] to start the application


## Issues / Bugs / Feature requests

Please use the issues tracker on https://bitbucket.org/MedPhysNL/pyrateshield
or send an e-mail to the authors to report issues/bugs or suggest features.


## Authors

Marcel Segbers (m.segbers@erasmusmc.nl)
Rob van Rooij (R.vanRooij-3@umcutrecht.nl)